#!/usr/bin/env sh



#--------[ Master Paths ]--------#
if ! [ "$(echo $PATH | grep sbin)" ]; then
  export PATH="$PATH:/sbin:/usr/sbin:/usr/local/sbin"
fi
if ! [ "$(echo $PATH | grep games)" ]; then
  export PATH="$PATH:/sbin:/usr/sbin:/usr/local/sbin:/usr/games"
fi



#--------[ System Variables ]--------#
export VISUAL=emacs
export EDITOR=vim



#--------[ CLI Flag Arguments ]--------#
for ARGV in $@; do
  case $ARGV in
    -d|--degub) export FAKE_MODE_DEBUG="TRUE" ;;
    -q|--quiet) export FAKE_MODE_QUIET="TRUE" ;;
  esac
done



#--------[ Terminal Colours ]--------#
FCOL0="\e[0m"
FCOL1="\e[37m\033[38;5;166m"
FCOL2="\e[37m\033[38;5;204m"
FCOL3="\e[37m\033[38;5;170m"
FCOLGRAD="lolcat -p 4 -S 6 -F 0.1"
FCOLBOLD="\e[1m"
FCOLITAL="\e[2;3m"



#--------[ Load Core Modules ]--------#
for MODULE in $(find /usr/share/fake-os/modules -name "*.sh"); do
  . $MODULE
done
unset MODULE



#--------[ Load User Modules ]--------#
if [ ! -d ~/.local/share/fake-os/modules ]; then
  mkdir -p ~/.local/share/fake-os/modules;
fi
for MODULE in $(find ~/.local/share/fake-os/modules -name "*.sh"); do
  . $MODULE
done
unset MODULE



#--------[ CLI Prompt ]--------#
if [ $(whoami) != "root" ]; then
  PS1="\[${FCOL0}\]\[[${FCOL3}\]\u\[${FCOL0}\]@\[${FCOL3}\]\h\[${FCOL0}\]] \W \$ "
else
  PS1="\[${FCOL0}\]\[[${FCOL1}\]\u\[${FCOL0}\]@\[${FCOL1}\]\h\[${FCOL0}\]] \W \$ "
fi




#--------[ Login Display ]--------#
echo ""
if [ ! "$FAKE_MODE_QUIET" ]; then


#--------[ Local Login ]--------#
  if [ "$ENV_LOGIN" ==  "local" ]; then
    if [ "$(command -v lolcat)" ]; then
      cat /usr/share/fake-os/assets/logos/logo_full.txt | $FCOLGRAD
    else
      cat /usr/share/fake-os/assets/logos/logo_full.txt
    fi


  #--------[ SSH Login ]--------#
  else
     if [ "$(command -v figlet)" ]; then
      figlet -w 1000 $(cat /etc/hostname)
    else
      echo "FAKE//OS Login: $(cat /etc/hostname)"
    fi
  fi


  #--------[ Login Info ]--------#
  echo ""
  echo -e "${FCOL1}user:${FCOL0} $(whoami)    ${FCOL2}login:${FCOL0} $ENV_LOGIN    ${FCOL3}system:${FCOL0} $ENV_ARCH $ENV_DISTRO $ENV_VTAG"
  echo ""
fi
