#!/usr/bin/env sh



#--------[ FAKE//OS Manager: Install Software ]--------#
_fake_manager_package_install () {



    #--------[ Basic Error Handeling ]--------#
    if [ ! "$2" ]; then
        _fake_layout_message "Error" "Must specify packages..."



    #--------[ Parse Package Arguments ]--------#
    else
        FAKE_PACKAGES=$(echo "$@" | sed -e 's/^install\ //g')



        #--------[ Get Pre-Installed System Pacakges ]--------#
        SYS_PACKAGES=""
        case $FAKE_MANAGER in
            apt) SYS_PACKAGES="$(apt list --installed 2>/dev/null)" ;;
            apk) SYS_PACKAGES="$(apk list --installed)" ;;
            dnf) SYS_PACKAGES="$(dnf list --installed)" ;;
            pacman) SYS_PACKAGES="$(pacman -Qq)" ;;
            paru) SYS_PACKAGES="$(paru -Qq)" ;;
        esac



        #--------[ Sort Packages Already Pre-Installed ]--------#
        FAKE_PACKAGES_NEW=""
        FAKE_PACKAGES_OLD=""
        for TMP_PACKAGE in $FAKE_PACKAGES; do
            if [ "$(echo $SYS_PACKAGES | grep $TMP_PACKAGE)" ]; then
                FAKE_PACKAGES_OLD="$FAKE_PACKAGES_OLD $TMP_PACKAGE"
            else
                FAKE_PACKAGES_NEW="$FAKE_PACKAGES_NEW $TMP_PACKAGE"
            fi
        done



        #--------[ Determin Available Packages ]--------#
        FAKE_PACKAGES_UNAVAILABLE=""
        FAKE_PACKAGES_INSTALL=""
        for TMP_PACKAGE in $FAKE_PACKAGES_NEW; do
            TMP_FOUND=FALSE
            case $FAKE_MANAGER in
                apk)
                    if [ "$(apk search --exact $TMP_PACKAGE)" ];then TMP_FOUND=TRUE; fi
                    ;;
                apt)
                    if [ "$(apt-cache search --names-only $TMP_PACKAGE | grep ^$TMP_PACKAGE\ )" ];then TMP_FOUND=TRUE; fi
                    ;;
                pacman)
                    if [ "$(pacman -Ssq $TMP_PACKAGE | grep ^$TMP_PACKAGE$)" ];then TMP_FOUND=TRUE; fi
                    if [ "$(pacman -Sg $TMP_PACKAGE | awk '{print $1}' | grep ^$TMP_PACKAGE$)" ];then TMP_FOUND=TRUE; fi
                    ;;
                paru)
                    if [ "$(paru -Ssq $TMP_PACKAGE | grep ^$TMP_PACKAGE$)" ];then TMP_FOUND=TRUE; fi
                    if [ "$(paru -Sg $TMP_PACKAGE | awk '{print $1}' | grep ^$TMP_PACKAGE$)" ];then TMP_FOUND=TRUE; fi
                    ;;
            esac
            if [ "$TMP_FOUND" == "TRUE" ]; then
                FAKE_PACKAGES_INSTALL="$FAKE_PACKAGES_INSTALL $TMP_PACKAGE"
            else
                FAKE_PACKAGES_UNAVAILABLE="$FAKE_PACKAGES_UNAVAILABLE $TMP_PACKAGE"
            fi
        done



        #--------[ Build Install Command ]--------#
        FAKE_CMD=""
        case $FAKE_MANAGER in
            apt) FAKE_CMD="sudo apt -y install $FAKE_PACKAGES_INSTALL" ;;
            apk) FAKE_CMD="sudo apk add $FAKE_PACKAGES_INSTALL" ;;
            dnf) FAKE_CMD="sudo dnf -y install $FAKE_PACKAGES_INSTALL" ;;
            pacman) FAKE_CMD="sudo pacman --noconfirm -S $FAKE_PACKAGES_INSTALL" ;;
            paru) FAKE_CMD="paru --noconfirm -S $FAKE_PACKAGES_INSTALL" ;;
        esac



        #--------[ Skip Pre-Installed Pacakges ]--------#
        if [ ! "$FAKE_PACKAGES_INSTALL" ]; then
            _fake_layout_message "Install" "No new packages..."
            if [ "$FAKE_PACKAGES_UNAVAILABLE" ]; then
                _fake_layout_submessage "unavailable" "$FAKE_PACKAGES_UNAVAILABLE";
                _fake_debug_error_pause
            fi
            if [ "$FAKE_PACKAGES_OLD" ]; then _fake_layout_submessage "up to date" "$FAKE_PACKAGES_OLD"; fi
            echo ""
        fi



        #--------[ Install New Packages ]--------#
        if [ "$FAKE_PACKAGES_INSTALL" ]; then
            _fake_layout_message "Install" "$FAKE_CMD"
            if [ "$FAKE_PACKAGES_UNAVAILABLE" ]; then
                _fake_layout_submessage "unavailable" "$FAKE_PACKAGES_UNAVAILABLE"
                _fake_debug_error_pause
            fi
            if [ "$FAKE_PACKAGES_OLD" ]; then _fake_layout_submessage "up to date" "$FAKE_PACKAGES_OLD"; fi
            _fake_layout_submessage "installing" "$FAKE_PACKAGES_INSTALL"
            echo ""
            if [ "$FAKE_MODE_DEBUG" ] || [ "$FAKE_MODE_SLOW" ]; then sleep 3; fi
            _fake_manager_package_automation "$FAKE_CMD"
            _fake_debug
        fi



    fi
}
